==> haskell-wai-websockets-3.0.1.1-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-LPZb3D51mQF1zz5v4gULrV
key: wai-websockets-3.0.1.1-LPZb3D51mQF1zz5v4gULrV
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 6629f3c1afa2cda03f683cd9e5efc1b3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-LPZb3D51mQF1zz5v4gULrV
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-HegeDw2KVvNKTqaIBuqg9O
    websockets-0.10.0.0-AoyfYrPV8hG6nHQYTZmXVO
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.1-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-m7zAKp4VVOBa9YAhRLPcx
key: wai-websockets-3.0.1.1-m7zAKp4VVOBa9YAhRLPcx
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: fb2e12f0e4b40c1d646497a1c63973f8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-m7zAKp4VVOBa9YAhRLPcx
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-Em8S4AXb0sj2I3tvlcNzHV
    websockets-0.10.0.0-JByLQEZljkc6BEzL7JWimZ
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
